#include "pitches.h"
#include <LiquidCrystal.h>

const int melody[] = { NOTE_C4, NOTE_G3, NOTE_G3, NOTE_A3, NOTE_G3, 0, NOTE_B3, NOTE_C4 };
const int times[] = { 4, 8, 8, 4, 4, 4, 4, 4 };
const int alarmTime = 30000;
int previousMillis = 0;

class Button {
  int pin;
  int buttonState;

public:
  Button(int inputPin) {
    pin = inputPin;
    buttonState = 0;
  }

  int getReading() {
    buttonState = digitalRead(pin);
    return buttonState;
  }
};

class Buzzer {
  int pin;

public:
  Buzzer(int inputPin) {
    pin = inputPin;
    pinMode(pin, INPUT);
  }

  void playTune() {
    for (int thisNote = 0; thisNote < 8; thisNote++) {
      int noteDuration = 1000 / times[thisNote];
      tone(pin, melody[thisNote], noteDuration);

      int pauseBetweenNotes = noteDuration * 1.30;
      delay(pauseBetweenNotes);
      noTone(pin);
    }
  }
};

Button button(41);
Buzzer buzzer(40);
LiquidCrystal lcd(14, 13, 12, 20, 19, 21);

void setup() {
  lcd.begin(16, 2);
  lcd.print("Time Remaining:");
}

void loop() {
  int status = button.getReading();
  if (status == 1) {
    previousMillis = millis();
    lcd.clear();
    lcd.setCursor(1, 0);
    lcd.print("Time Remaining:");
  }
  if (millis() - previousMillis >= alarmTime) {
    lcd.setCursor(0, 0);
    lcd.clear();
    lcd.print("Time's Up!");
    buzzer.playTune();
    delay(1000);
  } else {
    lcd.setCursor(0, 1);
    int time = (alarmTime - (millis() - previousMillis)) / 1000;
    lcd.print(String(time) + " seconds ");
  }
}